# tsst

tsst is a Python library for program traders are convenient to use our lib for program trading

## Installation

Use the package manager [pip]() to install tsst.

```bash
pip install tssst
```

## Usage

```python
import tsst


```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
